@@ -29,7 +29,7 @@ public:
     Q_REQUIRED_RESULT QString code(QWidget *) const override;
     Q_REQUIRED_RESULT QString help() const override;
     Q_REQUIRED_RESULT QWidget *createParamWidget(QWidget *parent) const override;
-    Q_REQUIRED_RESULT bool setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error) override;
+    void setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error) override;
     Q_REQUIRED_RESULT QStringList needRequires(QWidget *) const override;
     Q_REQUIRED_RESULT QUrl href() const override;
 
