@@ -29,7 +29,7 @@ public:
     Q_REQUIRED_RESULT QWidget *createParamWidget(QWidget *parent) const override;
     Q_REQUIRED_RESULT QString code(QWidget *) const override;
     Q_REQUIRED_RESULT QStringList needRequires(QWidget *parent) const override;
-    Q_REQUIRED_RESULT bool setParamWidgetValue(QXmlStreamReader &element, QWidget *parent, QString &error) override;
+    void setParamWidgetValue(QXmlStreamReader &element, QWidget *parent, QString &error) override;
 
     Q_REQUIRED_RESULT bool needCheckIfServerHasCapability() const override;
 
